#' Data collected by the 18th century physicist Henry Cavendish, who made 23 experimental
#' determinations of the earth's density (in g per cubic cm)
#' @name cavendish
#' @docType data
#' @return A data frame with 23 rows and 1 variable.
#' @keywords datasets
NULL

#' Data on the effect of three new diets on the blood coagulation times (in seconds)
#' in a set of animals.
#' @name coagulation
#' @docType data
#' @return A data frame with 18 rows and 2 variables.
#' @keywords datasets
NULL

#' Data on the aerobic colony counts (acc, measured in colony forming units per
#' millilitre) of ten selected keyboards with samples taken from four keys per
#' keyboard on a particular day. The keyboards were selected randomly from those
#' available in the computer laboratory.
#' @name contamination
#' @docType data
#' @return A data frame with 40 rows and 2 variables.
#' @references This data set was taken from an article in Microbiologist, June 2007.
#' @keywords datasets
NULL

#' Data on the frequency of chirps made by a striped ground cricket, at various ground
#' temperatures.
#' @name crickets
#' @docType data
#' @return A data frame with 15 rows and 2 variables.
#' @references Data collected by George W. Pierce in 1948.
#' @keywords datasets
NULL

#' Data collected by Malcolm on the height and shoe size of a random sample of students
#' @name malcolm
#' @docType data
#' @return A data frame with 52 rows and 2 variables.
#' @keywords datasets
NULL

#' Data on the logarithm of ornithine carbonyltransferase (a liver enzyme) in a random
#' sample of patients suffering from acute viral hepatitis.
#' @name hepatitis
#' @docType data
#' @return A data frame with 30 rows and 1 variable.
#' @keywords datasets
NULL

#' Data from an experiment to investigate how weight loss due to abrasion (in g/hr) of rubber
#' is affected by hardness (in degrees Shore) and tensile strength (in kg/cm^2).
#' @name abrasion
#' @docType data
#' @references This data set was taken from Davies and Goldsmith, Statistical Methods in
#' Research and Production, 4th edition.
#' @return A data frame with 30 rows and 3 variables.
#' @keywords datasets
NULL

#' Data on weekly gas consumption (in thousands of cubic feet) at 30 houses over 56 weeks.
#' The data includes the outside temperature (in degrees C), and the presence of insulation
#' (z=1: no insulation, z=2: insulation present).
#' @name insulation
#' @docType data
#' @return A data frame with 56 rows and 32 variables.
#' @keywords datasets
NULL

#' Data on 50 patients suffering from a chronic lung disease. Included is 30 measurements
#' of lung function (y1 to y30), along with patient age (in years), sex (0: female, 1:male),
#' and smoking status (0:non-smoker, 1:smoker).
#' @name lungs
#' @docType data
#' @return A data frame with 50 rows and 33 variables.
#' @keywords datasets
NULL

#' Data from an experiment to calibrate a near infrared reflectance instrument. Included is
#' the protein content (\%) as determined by a standard method (y1 to y30), and measurements
#' of reflectance at three different wavelengths (x1 to x3).
#' @name protein
#' @docType data
#' @return A data frame with 24 rows and 33 variables.
#' @keywords datasets
NULL

#' Data on the number of orders received by a small company for one of its products over time.
#' The data consists of 30 sets of 100 consecutive weeks.
#' @name sales
#' @docType data
#' @return A list containing 30 variables with 100 rows, and a variable with 1 row.
#' @keywords datasets
NULL

#' Data consisting of 160 consecutive daily IBM common stock closing prices.
#' @name IBMprices
#' @docType data
#' @references Box and Jenkins, Time Series Analysis, 1976.
#' @return A list containing a variable with 160 rows, and a variable with 1 row.
#' @keywords datasets
NULL

#' Data on the number of patients undergoing surgery and the number who died in hospital
#' in two areas of the USA, broken down by age and sex. A group number corresponding to
#' area and sex is provided, along with the midpoint of the age range (in years).
#' @name surgery
#' @docType data
#' @return A data frame with 32 rows with 4 variables.
#' @references Mosteller and Tukey, Data Analysis and Regression, 1977.
#' @keywords datasets
NULL

#' Data on successive waiting times (in minutes) between eruptions of the "Old Faithful"
#' geyser in Yellowstone National Park, Wyoming, USA.
#' @name oldfaithful
#' @docType data
#' @references Azzalini and Bowman, A look at some data on the Old Faithful geyser,
#' Journal of the Royal Statistical Society, Series C, 39, 357-366, (1990).
#' @return A list containing a variable with 299 rows, and a variable with 1 row.
#' @keywords datasets
NULL

#' Data on 33 leukaemia patients, classified by AG Group (1: AG positive, 2: AG negative).
#' For each patient white blood cell count and survival time (in weeks) is also provided.
#' @name leukaemia
#' @docType data
#' @references Feigl and Zelen, Estimation of exponential survival probabilities with
#' concomitant information, Biometrics, 21, 826-38 (1965).
#' @return A list containing 2 variables with 33 rows, and a variable with 1 row.
#' @keywords datasets
NULL

#'Data showing the outcomes from a set of babies, categorised as 'Full term' or
#''Premature', and 'alive at end of year 1' or 'died in year 1'.
#'The mothers are included, categorised as either 'Young' or 'Older' and 'Smokers'
#'or 'Non-smokers'.
#' @name babies
#' @docType data
#' @references Freeman, Applied Categorical Data Analysis, 1987.
#' @return A list containing a 4x4 matrix and 3 variables with 4 rows.
#' @keywords datasets
NULL

#' Data on the weights of a set of thirty young rats, measured over time (in days).
#' @name rats
#' @docType data
#' @references Gelfand, Hills, Racine-Poon, and Smith, Illustration of Bayesian inference
#'  in normal data models using Gibbs sampling, Journal of the American Statistical
#'  Association, 85, 972-85, (1990).
#' @return A list with 1 matrix and 1 variable.
#' @keywords datasets
NULL

#' Data showing the number of patients who were given different doses of a
#' certain drug, along with the number of patients who exhibited a
#' particular side effect.
#' @name sideeffects
#' @docType data
#' @return A data frame with 7 rows with 3 variables.
#' @keywords datasets
NULL

#' Data on the number of 'multi-fatality crashes' in the week following 17 known cases of
#''murder-suicide', together with an index of newspaper coverage.
#' @name aircraft
#' @references Phillips, Airplane accident fatalities increase just after newspaper
#' stories about murder and suicide, Science, 201, 748-750, (1978).
#' @docType data
#' @return A list containing 2 variables with 17 rows, and a variable with 1 row.
#' @keywords datasets
NULL

#' A dataset containing the time of birth (hh:mm), sex, and birth weight (in grams) for each
#' of 44 babies born in one 24-hour period at a Brisbane, Australia hospital.
#' Also included is the number of minutes since midnight for each birth.
#'
#' @name births
#' @docType data
#' @source \url{http://ww2.amstat.org/publications/jse/secure/v7n3/datasets.dunn.cfm}
#' @return A list containing 4 variables with 44 rows, and a variable with 1 row.
#' @keywords datasets
#'
NULL

#' A dataset containing the results of a study of the tonsil size (Normal, Large
#' or Very Large) of 1398 school children, along with whether or not they were
#' carriers of the bacterium Streptococcus pyogenes.
#'
#' @name tonsils
#' @docType data
#' @source W. J. Krzanowski, Principles of Multivariate Analysis, Oxford: Oxford
#' University Press, 1988.
#' @return A list containing 1 variable with 6 rows.
#' @keywords datasets
#'
NULL

#' A random sample of granite gravestones was taken from a cemetery in Savannah,
#' a city along the southeast coast of the USA (coastal) and a cemetery in
#' Macon, Georgia, a town located 170 miles inland from Savannah (inland).
#' The dataset consists of the age of each gravestone (the difference between
#' the current year and the year the person died), the depth of degradation (in
#' mm) as determined by the lettering alteration method, and the location of the
#' gravestone where the value of location is 0 for coastal and 1 for inland.
#'
#' @name granite
#' @docType data
#' @source T.C. Meierdin, Marble weathering rates: a transect of the United States.
#' Physical Geography, 2, pp. 1-18, (1981)
#' @return A list containing 3 variables with 25 rows, and a variable with 1 row.
#' @keywords datasets
#'
NULL

#' The number of spruce moths found in traps after 48 hours by location
#' of trap in tree (top branches, middle branches, lower branches, ground) and type
#' of lure in the trap (scent, sugar, chemical).
#' @name moths
#' @docType data
#' @return A list containing 3 variables with 60 rows, and a variable with 1 row.
#' @keywords datasets
NULL

#' The prices of 75cl bottles of Barolo wines in July 2010 from the website
#' of a Italian wine reseller. The price does not include the delivery charge.
#' @name barolo
#' @docType data
#' @return A list containing a variable with 103 rows, and a variable with 1 row.
#' @keywords datasets
NULL

#' The number of roots produced by 270 micropropagated shoots of the
#' apple cultivar Trajan. During the rooting period, all shoots
#' were maintained under identical conditions but the shoots themselves
#' were cultured on media containing different concentrations of
#' cytokinin BAP, in growth cabinets with an 8 or 16 hour photoperiod.
#' Thus each experimental condition is decribed by two factors: BAP
#' concentration (2.2, 4.4, 8.8 and 17.6 $\\mu M$) and photoperiod (8
#' and 16 hours).
#' @name shoots
#' @docType data
#' @return A list containing 3 variables with 270 rows.
#' @keywords datasets
NULL

#' The breaking strengths of 63 glass fibres of length 1.5cm.
#' @name glassfibre
#' @docType data
#' @return A list containing a variable with 63 rows, and a variable with 1 row.
#' @keywords datasets
NULL

#' The chlorobenzene exposure concentrations (15 min TWAs) in ppm for a
#' chemical worker during a full workshift for 30 consecutive days.
#' @name exposure
#' @docType data
#' @return A list containing a variable with 31 rows, and a variable with 1 row.
#' @keywords datasets
NULL
